import { TypedEmitter } from 'tiny-typed-emitter';
import { ProductSchema } from '@byondrnd/showroom-schemas';
export declare type OnSceneLoaded = (eventData: {
    zone: number;
}) => void;
export declare type OnVisualizerLoaded = () => void;
export declare type OnProductChange = (eventData: {
    product: ProductSchema.IProduct;
}) => void;
export declare type onHotspotClicked = (eventData: {
    application: string;
}) => void;
export declare type onProductAddedToFavorite = (eventData: {
    favorites: string[];
}) => void;
export declare type onSetAddedToFavorite = (eventData: {
    favoritesSet: string[][];
}) => void;
export declare type onProductAddedToCart = (eventData: {
    cart: string[];
}) => void;
export declare type onProductRemovedFromFavorite = (eventData: {
    favorites: string[];
}) => void;
export declare type onSetRemovedFromFavorite = (eventData: {
    favoritesSet: string[][];
}) => void;
export declare type onProductRemovedFromCart = (eventData: {
    cart: string[];
}) => void;
interface IEventSystem {
    sceneLoaded: OnSceneLoaded;
    visualizerLoaded: OnVisualizerLoaded;
    productChanged: OnProductChange;
    hotspotClicked: onHotspotClicked;
    productAddedToFavorite: onProductAddedToFavorite;
    setAddedToFavorite: onSetAddedToFavorite;
    productAddedToCart: onProductAddedToCart;
    productRemovedFromFavorite: onProductRemovedFromFavorite;
    setRemovedFromFavorite: onSetRemovedFromFavorite;
    productRemovedFromCart: onProductRemovedFromCart;
}
export declare abstract class EventSystem extends TypedEmitter<IEventSystem> {
    abstract initAndLoad(): any;
    abstract GetProductList(filters: {
        name: string;
        options: string[];
    }[]): Array<ProductSchema.IProduct>;
    abstract GetHotspotList(): string[];
    abstract GetFilters(): {
        name: string;
        options: string[];
    }[];
    abstract displayProduct(productId: string): Promise<void>;
    abstract addProductToFavorite(productId: string): any;
    abstract addSetToFavorite(productIds: string[]): any;
    abstract addProductsToCart(productIds: string[]): any;
    abstract removeProductFromFavorite(productId: string): any;
    abstract removeSetFromFavorite(productIds: string[]): any;
    abstract removeProductsFromCart(productId: string[]): any;
}
export {};
